==> lcov-server-1.2.4.tgz: package/distributed/bin/lcov-server.js <==
#!/usr/bin/env node
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

require('babel-polyfill');

var updateNotifier = require('update-notifier');

var cli = require('../lib/cli');

var pkg = require('../package.json');

updateNotifier({ pkg: pkg }).notify();

var args = process.argv.slice(2);

var program = {};

args.forEach(function (a, i) {
  switch (a) {
    case '-v':
    case '--version':
      console.log('v' + require('../package.json').version); // eslint-disable-line
      process.exit(0);
      break;
    case 'help':
    case '-h':
    case '--help':
      console.log('' + // eslint-disable-line
      '\n    Usage: lcov-server [options]\n\n    Commands:\n    \n      upload, --upload, -u [server ] Set the url to upload lcov data too (default: http://localhost:8080)\n      serve, -s, --serve             Pass this option to startup a lcov-server instance\n      version, -v, --version           output the version number\n      help, -h, --help              output usage information\n\n    Options:\n\n      db, -d, --db [db]           Set the db connection (default: mongodb://localhost:32768/lcov-server)\n      parser, -p, --parser <parser>   Set the parser value [lcov, cobertura, golang, jacoco], defaults to lcov (default: lcov)\n      basePath, -bp, --basePath <path>  The path that defines the base directory where the files that were covered will be located\n  ');
      process.exit(0);
      break;
    case '-db':
    case '--db':
    case 'db':
      program.db = args[i + 1];
      break;
    case '-u':
    case '--upload':
    case 'upload':
      program.upload = args[i + 1];
      break;
    case '-s':
    case '--serve':
    case 'serve':
      program.serve = true;
      break;
    case '-p':
    case '--parser':
    case 'parser':
      program.parser = args[i + 1];
      if (['lcov', 'cobertura', 'golang', 'jacoco'].indexOf(program.parser) === -1) {
        console.error('parser ' + program.parser + ' not supported'); // eslint-disable-line
        process.exit(1);
      }
      break;
    case '-bp':
    case '--basePath':
    case 'basePath':
      program.basePath = args[i + 1];
      break;
  }
});

var parser = program.parser,
    upload = program.upload,
    serve = program.serve,
    db = program.db,
    basePath = program.basePath;


if (serve) {
  process.env.MONGO_URL = process.env.MONGO_URL || db;

  require('../index');
} else {
  var input = '';
  process.stdin.resume();
  process.stdin.setEncoding('utf8');
  process.stdin.on('data', function (chunk) {
    input += chunk;
  });
  process.stdin.on('end', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            try {
              response = cli({ parser: parser, input: input, url: upload, basePath: basePath });

              if (response.error) {
                console.error('coverage not sent with reason:\n ' + response.error); // eslint-disable-line
              } else {
                console.log('\n coverage sent successfully 💚 \n'); // eslint-disable-line
              }
            } catch (ex) {
              console.error('coverage could not be parsed with reason:\n ' + ex.toString()); // eslint-disable-line
            }

          case 1:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));
}

==> lcov-server-1.2.5.tgz: package/distributed/bin/lcov-server.js <==
#!/usr/bin/env node
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

require('babel-polyfill');

var updateNotifier = require('update-notifier');

var cli = require('../lib/cli');

var pkg = require('../package.json');

updateNotifier({ pkg: pkg }).notify();

var args = process.argv.slice(2);

var program = {};

args.forEach(function (a, i) {
  switch (a) {
    case '-v':
    case '--version':
      console.log('v' + require('../package.json').version); // eslint-disable-line
      process.exit(0);
      break;
    case 'help':
    case '-h':
    case '--help':
      console.log('' + // eslint-disable-line
      '\n    Usage: lcov-server [options]\n\n    Commands:\n\n      upload, --upload, -u [server ] Set the url to upload lcov data too (default: http://localhost:8080)\n      serve, -s, --serve             Pass this option to startup a lcov-server instance\n      version, -v, --version           output the version number\n      help, -h, --help              output usage information\n\n    Options:\n\n      db, -d, --db [db]           Set the db connection (default: mongodb://localhost:32768/lcov-server)\n      parser, -p, --parser <parser>   Set the parser value [lcov, cobertura, golang, jacoco], defaults to lcov (default: lcov)\n      basePath, -bp, --basePath <path>  The path that defines the base directory where the files that were covered will be located\n  ');
      process.exit(0);
      break;
    case '-db':
    case '--db':
    case 'db':
      program.db = args[i + 1];
      break;
    case '-u':
    case '--upload':
    case 'upload':
      program.upload = args[i + 1];
      break;
    case '-s':
    case '--serve':
    case 'serve':
      program.serve = true;
      break;
    case '-p':
    case '--parser':
    case 'parser':
      program.parser = args[i + 1];
      if (['lcov', 'cobertura', 'golang', 'jacoco'].indexOf(program.parser) === -1) {
        console.error('parser ' + program.parser + ' not supported'); // eslint-disable-line
        process.exit(1);
      }
      break;
    case '-bp':
    case '--basePath':
    case 'basePath':
      program.basePath = args[i + 1];
      break;
  }
});

var parser = program.parser,
    upload = program.upload,
    serve = program.serve,
    db = program.db,
    basePath = program.basePath;


if (serve) {
  process.env.MONGO_URL = process.env.MONGO_URL || db || 'mongodb://localhost:32768/lcov-server';

  require('../index');
} else {
  var input = '';
  process.stdin.resume();
  process.stdin.setEncoding('utf8');
  process.stdin.on('data', function (chunk) {
    input += chunk;
  });
  process.stdin.on('end', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            try {
              response = cli({ parser: parser, input: input, url: upload, basePath: basePath });

              if (response.error) {
                console.error('coverage not sent with reason:\n ' + response.error); // eslint-disable-line
              } else {
                console.log('\n coverage sent successfully 💚 \n'); // eslint-disable-line
              }
            } catch (ex) {
              console.error('coverage could not be parsed with reason:\n ' + ex.toString()); // eslint-disable-line
            }

          case 1:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));
}
